@@ -78,12 +78,10 @@ from .vine import *
 from .vk import *
 from .w56 import *
 from .wanmen import *
-from .xiami import *
 from .xinpianchang import *
-from .yinyuetai import *
 from .yixia import *
 from .youku import *
 from .youtube import *
 from .zhanqi import *
 from .zhibo import *
-from .zhihu import *
\ No newline at end of file
+from .zhihu import *
